==> ifrit_3.2.8.orig.tar.gz: ifrit-3.2.8/core/iartifactcorrector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Helper class for correcting visual artifacts (effectively, VTK bugs)
//

#ifndef IARTIFACTCORRECTOR_H
#define IARTIFACTCORRECTOR_H


#include "igenericfilter.h"
#include <vtkDepthSortPolyData.h>


class vtkProperty;
class vtkRenderer;


class iArtifactCorrector : public iGenericPolyDataToPolyDataFilter<vtkDepthSortPolyData>
{
	
	IGENERICFILTER_DECLARE(iArtifactCorrector,vtkDepthSortPolyData);

public:
	
	static void Enable(bool s);
	static bool IsEnabled(){ return mIsEnabled; }

	void CorrectArtifacts(vtkRenderer *ren, vtkProperty *prop);

protected:
	
	virtual ~iArtifactCorrector();

	virtual void ProduceOutput();
	virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop);

private:

	static bool mIsEnabled;

	bool mIsActive;
};

#endif

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/core/iartifactcorrector.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Helper class for correcting visual artifacts (effectively, VTK bugs)
//

#ifndef IARTIFACTCORRECTOR_H
#define IARTIFACTCORRECTOR_H


#include "igenericfilter.h"
#include <vtkDepthSortPolyData.h>


class vtkPolyDataMapper;
class vtkProperty;
class vtkRenderer;
class vtkTimerLog;


class iArtifactCorrector : public iGenericPolyDataToPolyDataFilter<vtkDepthSortPolyData>
{
	
	IGENERICFILTER_DECLARE(iArtifactCorrector,vtkDepthSortPolyData);

public:
	
	static void Enable(bool s);
	static bool IsEnabled(){ return mIsEnabled; }

	void CorrectArtifacts(vtkRenderer *ren, vtkProperty *prop, vtkPolyDataMapper *mapper, double time);

protected:
	
	virtual ~iArtifactCorrector();

	virtual void ProduceOutput();
	virtual bool HasArtifacts(vtkRenderer *ren, vtkProperty *prop);

private:

	static bool mIsEnabled;
	vtkTimerLog *mTimer;
	double mLastAllocatedTime;

	void SetInput(vtkDataObject *); // not impelmeneted
};

#endif
